Trees

[hide private]
[frames] | no frames]

## Module Hierarchy

- cheesecake

- cheesecake.ast_pp
- cheesecake.cheesecake_index: Cheesecake: How tasty is your code?
- cheesecake.codeparser
- cheesecake.logger
- cheesecake.model: Code borrowed from Michael Hudson's docextractor package with the author's permission.
- cheesecake.subprocess: subprocess - Subprocesses with accessible I/O streams This module allows you to spawn processes, connect to their input/output/error pipes, and obtain their return codes.
- cheesecake.util: Utility functions for Cheesecake project.

## Class Hierarchy

- cheesecake.subprocess.STARTUPINFO
- cheesecake.subprocess.pywintypes
- exceptions.Exception: Common base class for all exceptions.
  - cheesecake.cheesecake_index.CheesecakeError: Custom exception class for Cheesecake-specific errors.
  - exceptions.StandardError: Base class for all standard Python exceptions.
    - exceptions.EnvironmentError: Base class for I/O related errors.
      - exceptions.IOError: I/O operation failed.
  - cheesecake.subprocess.ProcessError: This exception is raised when there is an error calling a subprocess.
- object: The most base type
  - cheesecake.util.StdoutRedirector: Redirect stdout to a temporary file.
  - cheesecake.subprocess.Popen
  - cheesecake.logger.Message
  - cheesecake.logger.Producer: Log producer API which sends messages to be logged to a 'consumer' object, which then prints them to stdout, stderr, files, etc.
    - cheesecake.logger.MultipleProducer
  - cheesecake.cheesecake_index.Index: Class describing one index.
    - cheesecake.cheesecake_index.IndexPyPIDownload: Check if package was successfully downloaded from PyPI and how far from it actual package was.
    - cheesecake.cheesecake_index.CheesecakeIndex
    - cheesecake.cheesecake_index.IndexInstall: Check if package can be installed via "python setup.py" command.
    - cheesecake.cheesecake_index.IndexCodeKwalitee
    - cheesecake.cheesecake_index.IndexDocstrings: Compute how many objects have relevant docstrings.
    - cheesecake.cheesecake_index.IndexUnpackDir: Check if package unpack directory resembles package archive name.
    - cheesecake.cheesecake_index.IndexFormattedDocstrings: Compute how many of existing docstrings include any formatting, like epytext or reST.
    - cheesecake.cheesecake_index.IndexGeneratedFiles: Lower score for automatically generated files that should not be present in a package.
    - cheesecake.cheesecake_index.IndexUnitTested: Check if the package have unit tests which can be easily found by any of known test frameworks.
    - cheesecake.cheesecake_index.IndexUrlDownload: Give points for successful downloading of a package.
    - cheesecake.cheesecake_index.IndexUnitTests: Compute unittest index as percentage of methods/functions that are exercised in unit tests.
    - cheesecake.cheesecake_index.IndexDocumentation
    - cheesecake.cheesecake_index.IndexInstallability
    - cheesecake.cheesecake_index.FilesIndex
      - cheesecake.cheesecake_index.IndexSetupPy: Reward packages that have setup.py file.
      - cheesecake.cheesecake_index.IndexRequiredFiles: Check for existence of important files, like README or INSTALL.
    - cheesecake.cheesecake_index.IndexPyLint: Compute pylint index of the whole package.
    - cheesecake.cheesecake_index.IndexUnpack: Give points for successful unpacking of a package archive.
  - cheesecake.model.ModuleVistor
  - cheesecake.model.ImportStarFinder
  - cheesecake.cheesecake_index.Cheesecake: Computes 'goodness' of Python packages.
  - cheesecake.model.Documentable
    - cheesecake.model.Module
    - cheesecake.model.Function
    - cheesecake.model.Class
    - cheesecake.model.Package
  - cheesecake.cheesecake_index.OneOf
  - cheesecake.ast_pp.SourceWriter
  - type: type(object) -> the object's type type(name, bases, dict) -> a new type
    - cheesecake.cheesecake_index.NameSetter
  - cheesecake.logger.File
    - cheesecake.logger.Path
  - cheesecake.codeparser.CodeParser: Information about the structure of a Python module.
  - cheesecake.model.System
  - cheesecake.cheesecake_index.Step: Single step during computation of package score.
    - cheesecake.cheesecake_index.StepByVariable: Step which is always run if given Cheesecake instance variable is true.